/*
integrit - file integrity verification system
Copyright (C) 2000 Ed Cashin

You can redistribute this program and/or modify it under the terms of
the Artistic License as published by the Open Source Initiative,
currently at the following URL:

    http://www.opensource.org/licenses/artistic-license.html

THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

*/
#ifndef	ELC_RULES_H
#define	ELC_RULES_H

typedef enum ruleflag {
  RULE_IGNORE		 = 0x01,
  RULE_NOCHILDREN	 = 0x02,
  RULE_SUM		 = 0x04,
  RULE_INODE		 = 0x08,
  RULE_PERMS		 = 0x10,
  RULE_NLINK		 = 0x20,
  RULE_UID		 = 0x40,
  RULE_GID		 = 0x80,
  RULE_SIZE		 = 0x100,
  RULE_ATIME		 = 0x200,
  RULE_MTIME		 = 0x400,
#if 0
  RULE_CTIME		 = 0x800,
#endif
} ruleflag;

#endif
